# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.0]
### Added
- Tokens registry.
### Changed
- Reduced amount of code dependent on simplejwt. Small improvements because of that and more flexible and extendable code as result.

## [0.1.4]
### Added
- Translation strings.

## [0.1.1]
Initial version.
